##  Overview
In this phase, you will leverage SAP LeanIX to build high-level transformation scenarios and choose the best path for the roll-out. Using the insights from the Discover phase and adding Initiatives (i.e. projects) to your SAP LeanIX inventory, you will have the information needed for detailed transformation roadmap planning. Consider improving your application landscape by referencing the [TIME](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD) or [6R](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) assessment results from the [previous phase](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD "Establish architecture transparency in ERP transformation. Understand and assess your 'as-is architecture' and report effectively."), and strategically plan when to eliminate specific applications for improvement.
The aim is to prepare a detailed target architecture and choose the ideal transformation path to reach that state. As a first step, do an assessment of the project landscape (using Program and Project Fact Sheet subtypes (including hierarchies)). Identify applications that are affected and have dependencies on your ERP transformation project. You will start involving Project Managers to work in SAP LeanIX.
In this phase, do the following:
  1. [Enrich data](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bca9a7a441014a34c91860f299fc5__step_1._enrich_data): Enrich data by adding Initiatives (i.e. Projects and Programs Subtypes) and Milestones, and structuring your transformation program.
  2. [Evaluate data](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bca9a7a441014a34c91860f299fc5__step_2._evaluate_data): Evaluate transformation scenarios, transformation impact on the business, application integrations, and project dependencies.
  3. [Report and communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bca9a7a441014a34c91860f299fc5__step_3._report_and_communicate): Build on the dashboard you created in the [previous phase](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD "Establish architecture transparency in ERP transformation. Understand and assess your 'as-is architecture' and report effectively."), and add relevant Reports and KPIs for overview and communication.


The following overview gives a "Definition of Done" and Milestones that you should achieve in this phase. Relevant Reports and KPIs are also illustrated next to them. For a more detailed explanation, refer to the Report and Communicate section in each phase.
Milestones |  KPIs/Reports
---|---
Define Initiatives with Milestones to reach the Objectives and create scenarios for different roll-out plans. |  ![Image 2](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274134567a44101492d6d6ebd5893077_LowRes.png)
Have a high-level project roadmap with Milestones in place and dependencies between initiatives/projects for different scenarios (and Diagrams related to Initiatives). |  ![Image 3](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747c8ab7a4410149be7f633ab7e0f44_LowRes.png)
Have mandatory attributes for Initiatives (responsibles, dependencies between initiatives, cost) defined. |  ![Image 4](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755cbc57a441014b479c0c5d573a07f_LowRes.png)


